@@ -3,6 +3,6 @@
 #
 XML_LIBDIR="-L/usr/local/lib"
 XML_LIBS="-lxml -lz  "
-XML_INCLUDEDIR="-I/usr/local/include/gnome-xml"
-MODULE_VERSION="xml-1.8.17"
+XML_INCLUDEDIR="-I/usr/local/include/libxml -I/usr/local/include"
+MODULE_VERSION="xml-2.2.4"
 
